# server.py

from telegram.ext import Application, CommandHandler, MessageHandler, filters, ConversationHandler, CallbackQueryHandler
from telegram import Update
from logging_script import logger, error_logger  # Import both loggers
from config import TOKEN, ADMIN_IDs
from start import start
from db import database_dependencies
from admin import admin_message_handler, access_handler, cancel_handler, add_access_start, filter_selection, filter_confirmation
from user import user_panel
from config import ACCESS, ADMIN, FILTER_SELECTION, FILTER_CONFIRMATION, filters_list
from scheculed import send_post, crawl_platforms, send_backup

def main() -> None:
    logger.info("Starting bot")
    application = Application.builder().token(TOKEN).build()

    database_dependencies()

    application.add_handler(CommandHandler("start", start))

    conv_handler = ConversationHandler(
        entry_points=[MessageHandler(filters.Regex("^(افزودن دسترسی➕|گزارش دسترسی ها📈|گزارش📈|حذف دسترسی🔒)$"), admin_message_handler)],
        states={
            ACCESS: [MessageHandler(filters.Regex("^.\d+$"), access_handler)],
            FILTER_SELECTION: [CallbackQueryHandler(filter_selection)],
            FILTER_CONFIRMATION: [CallbackQueryHandler(filter_confirmation)],
            ADMIN: [MessageHandler(filters.Regex("^(افزودن دسترسی➕|گزارش دسترسی ها📈|گزارش📈|حذف دسترسی🔒)$"), admin_message_handler)],
        },
        fallbacks=[MessageHandler(filters.Regex("^(برگشت)$"), cancel_handler)],
    )

    application.add_handler(conv_handler)
    application.add_handler(MessageHandler(filters.Regex("پنل کاربری📄"), user_panel))

    job_queue = application.job_queue
    job_queue.run_repeating(crawl_platforms, interval=400, first=25)
    job_queue.run_repeating(send_post, interval=380, first=200)

    # send backup file each 6 hours
    # job_queue.run_repeating(send_backup, interval=21600, first=5)

    # job_queue.run_repeating(send_post, interval=340, first=10)
    # Exception handling to log errors
    async def error_handler(update: Update, context) -> None:
        logger.error("Exception while handling an update:", exc_info=context.error)
        error_logger.error("Exception while handling an update:", exc_info=context.error)

    application.add_error_handler(error_handler)

    application.run_polling(allowed_updates=Update.ALL_TYPES)

if __name__ == "__main__":
    main()
